# Commencez !

Bienvenue dans Rapunzel, un environnement de développement moderne pour Python et R. Voici quelques raccourcis clavier pratiques.

## Travailler avec des dossiers et fichiers de projet

- [`Ctrl+Maj+O` : Ouvrir le dossier du projet](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O` : Ouvrir un fichier à partir des dossiers du projet](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N` : Créer un document vierge](opensesame://event.ide_new_file)

## Faire les choses rapidement

- [`Ctrl+Maj+P` : Activer la palette de commandes](opensesame://event.command_palette_activate)
- `Ctrl+R` : Aller à une fonction ou classe

## Exécuter du code

- `F5` : Exécuter le projet ou le fichier
- `F9` : Exécuter la sélection, la cellule ou la ligne actuelle
